@@ -178,6 +178,13 @@ class ICRF(object):
                 Angle(radians=lon),
                 Distance(au=d))
 
+    def to_skycoord(self, unit=None):
+        """Convert this distance to an AstroPy ``SkyCoord`` object."""
+        from astropy.coordinates import SkyCoord
+        from astropy.units import au
+        x, y, z = self.position.au
+        return SkyCoord(representation='cartesian', x=x, y=y, z=z, unit=au)
+
     def _to_spice_frame(self, name):
         vector = self.position.au
         vector = inertial_frames[name].dot(vector)
@@ -367,10 +374,10 @@ def _to_altaz(position_au, observer_data, temperature_C, pressure_mbar):
     """Compute (alt, az, distance) relative to the observer's horizon.
 
     """
-    try:
-        elevation_m = observer_data.elevation_m
-        R = observer_data.altaz_rotation
-    except AttributeError:
+    elevation_m = observer_data.elevation_m
+    R = observer_data.altaz_rotation
+
+    if (elevation_m is None) or (R is None):
         raise ValueError('to compute an altazimuth position, you must'
                          ' observe from a specific Earth location that'
                          ' you specify using a Topos instance')
