@@ -527,6 +527,11 @@ class Time(object):
             return NotImplemented
         return self.tt == other_time.tt
 
+    def __sub__(self, other_time):
+        if not isinstance(other_time, Time):
+            return NotImplemented
+        return self.tt - other_time.tt
+
 def julian_day(year, month=1, day=1):
     """Given a proleptic Gregorian calendar date, return a Julian day int."""
     janfeb = month < 3
@@ -669,10 +674,9 @@ def build_delta_t_table(delta_t_recent):
     return table
 
 def _utc_datetime_to_tai(leap_dates, leap_offsets, dt):
-    try:
-        utc_datetime = dt.astimezone(utc)
-    except ValueError:
+    if dt.tzinfo is None:
         raise ValueError(_naive_complaint)
+    utc_datetime = dt.astimezone(utc)
     tup = utc_datetime.utctimetuple()
     year, month, day, hour, minute, second, wday, yday, dst = tup
     return _utc_to_tai(leap_dates, leap_offsets, year, month, day,
